# Solitude is a interactive story with four endings.
# Copyright (C) 2012 Ryan Martin
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import random
import sys, getopt 

import pyglet

import GameData

from Stage import Stage
from Wilderness import Wilderness
from City import City
from Mansion import Mansion
from Cubefarm import Cubefarm
from Farm import Farm
from Shrine import Shrine
from Farmhouse import Farmhouse

fullscreen=False
vsync=False
music=False

def usage():
    print "-h, --help                 this message"
    print "-f, --fullscreen           launch fullscreen"
    print "-v, --vsync                enable vsync"
    print "-m, --music                enable music"

try:
    opts, args = getopt.getopt(sys.argv[1:], "hfvm", ["fullscreen", "vsync", "music"])
except getopt.GetoptError, err:
    # print help information and exit:
    print str(err) # will print something like "option -a not recognized"
    usage()
    sys.exit(2)
for o, a in opts:
    if o in ("-h", "--help"):
        usage()
        sys.exit()
    elif o in ("-f", "--fullscreen"):
        fullscreen=True
    elif o in ("-v", "--vsync"):
        vsync=True
    elif o in ("-m", "--music"):
        music=True
    else:
        assert False, "unhandled option"

def on_key_press(symbol, modifiers):
    key=pyglet.window.key
    if symbol==key.ESCAPE:
        stage.show_yes_no_dialog("Exit game?", window.close)
    elif symbol==key.X:
        stage.show_yes_no_dialog("Exit game?", window.close)

def run():
    global stage
    stage=Wilderness()
    #stage=City()
    #stage=Mansion()
    #stage=Cubefarm()
    #stage=Farm()
    #stage=Shrine()
    #stage=Farmhouse()
    stage.display(music)
    pyglet.app.run()

def switch_stage(name):
    global stage
    if music and stage.music:
        stage.music_player.pause()
    del stage
    stage=globals()[name]()
    stage.display(music)

pyglet.resource.path = ['sprites', 'music', 'json']
pyglet.resource.reindex()

if fullscreen:
    window=pyglet.window.Window(caption=GameData.options.name, fullscreen=True)
    GameData.options.fullscreen=True
else: 
    window=pyglet.window.Window(width=GameData.options.width, height=GameData.options.height, caption=GameData.options.name)

window.on_key_press=on_key_press
window.set_vsync(vsync)

pyglet.gl.glEnable(pyglet.gl.GL_BLEND)
pyglet.gl.glBlendFunc(pyglet.gl.GL_SRC_ALPHA, pyglet.gl.GL_ONE_MINUS_SRC_ALPHA)

